Installation
------------
Its dependencies are:

- `black`_
- `more-itertools`_
- `rich`_
- `tomli`_
- `pathspec`_


To install it, use

.. code:: bash

   python -m pip install blackdoc

or with ``conda``:

.. code:: bash

   conda install -c conda-forge blackdoc


.. _more-itertools: https://more-itertools.readthedocs.io/
.. _black: https://black.readthedocs.io/en/stable/
.. _rich: https://rich.readthedocs.io/en/latest/
.. _tomli: https://github.com/hukkin/tomli
.. _pathspec: https://python-path-specification.readthedocs.io/en/latest/
